==> typo3_src-9.5.14.tar.gz: typo3_src-9.5.14/typo3/sysext/install/Configuration/ExtensionScanner/Php/ConstantMatcher.php <==
<?php
return [
    'TYPO3_DLOG' => [
        'restFiles' => [
            'Breaking-82162-GlobalErrorConstantsRemoved.rst',
        ],
    ],
    'TYPO3_ERROR_DLOG' => [
        'restFiles' => [
            'Breaking-82162-GlobalErrorConstantsRemoved.rst',
        ],
    ],
    'TYPO3_EXCEPTION_DLOG' => [
        'restFiles' => [
            'Breaking-82162-GlobalErrorConstantsRemoved.rst',
        ],
    ],
    'TYPO3_user_agent' => [
        'restFiles' => [
            'Breaking-82296-UserAgentConstantRemoved.rst',
        ],
    ],
    'T3_ERR_SV_GENERAL' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_NOT_AVAIL' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_WRONG_SUBTYPE' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_NO_INPUT' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_FILE_NOT_FOUND' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_FILE_READ' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_FILE_WRITE' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_PROG_NOT_FOUND' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'T3_ERR_SV_PROG_FAILED' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
        ],
    ],
    'PATH_thisScript' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
        ],
    ],
    'PATH_typo3' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
        ],
    ],
    'PATH_typo3conf' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
        ],
    ],
    'TYPO3_OS' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
        ],
    ],
    'NUL' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TAB' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'SUB' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_SYSTEMREQUIREMENTS' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_DOWNLOAD' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_SECURITY' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_CONTRIBUTE' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_CONSULTANCY' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_DOCUMENTATION_TSCONFIG' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_DOCUMENTATION_TSREF' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_DOCUMENTATION' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'TYPO3_URL_MAILINGLISTS' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
        ]
    ],
    'PATH_site' => [
        'restFiles' => [
            'Deprecation-85285-DeprecatedSystemConstants.rst',
        ]
    ]
];

==> typo3_src-10.3.0.tar.gz: typo3_src-10.3.0/typo3/sysext/install/Configuration/ExtensionScanner/Php/ConstantMatcher.php <==
<?php
return [
    'TYPO3_DLOG' => [
        'restFiles' => [
            'Breaking-82162-GlobalErrorConstantsRemoved.rst',
        ],
    ],
    'TYPO3_ERROR_DLOG' => [
        'restFiles' => [
            'Breaking-82162-GlobalErrorConstantsRemoved.rst',
        ],
    ],
    'TYPO3_EXCEPTION_DLOG' => [
        'restFiles' => [
            'Breaking-82162-GlobalErrorConstantsRemoved.rst',
        ],
    ],
    'TYPO3_user_agent' => [
        'restFiles' => [
            'Breaking-82296-UserAgentConstantRemoved.rst',
        ],
    ],
    'T3_ERR_SV_GENERAL' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_NOT_AVAIL' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_WRONG_SUBTYPE' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_NO_INPUT' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_FILE_NOT_FOUND' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_FILE_READ' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_FILE_WRITE' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_PROG_NOT_FOUND' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'T3_ERR_SV_PROG_FAILED' => [
        'restFiles' => [
            'Deprecation-85123-ConstantsRelatedToServices.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'PATH_thisScript' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'PATH_typo3' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'PATH_typo3conf' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'TYPO3_OS' => [
        'restFiles' => [
            'Feature-84153-IntroduceAGenericEnvironmentClass.rst',
            'Deprecation-85285-DeprecatedSystemConstants.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ],
    ],
    'NUL' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TAB' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'SUB' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_SYSTEMREQUIREMENTS' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_DOWNLOAD' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_SECURITY' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_CONTRIBUTE' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_CONSULTANCY' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_DOCUMENTATION_TSCONFIG' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_DOCUMENTATION_TSREF' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_DOCUMENTATION' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_URL_MAILINGLISTS' => [
        'restFiles' => [
            'Deprecation-85793-SeveralConstantsFromSystemEnvironmentBuilder.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'PATH_site' => [
        'restFiles' => [
            'Deprecation-85285-DeprecatedSystemConstants.rst',
            'Breaking-87193-DeprecatedFunctionalityRemoved.rst',
        ]
    ],
    'TYPO3_version' => [
        'restFiles' => [
            'Deprecation-90007-GlobalConstantsTYPO3_versionAndTYPO3_branch.rst'
        ]
    ],
    'TYPO3_branch' => [
        'restFiles' => [
            'Deprecation-90007-GlobalConstantsTYPO3_versionAndTYPO3_branch.rst'
        ]
    ],
    'TYPO3_copyright_year' => [
        'restFiles' => [
            'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
        ]
    ],
    'TYPO3_URL_GENERAL' => [
        'restFiles' => [
            'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
        ]
    ],
    'TYPO3_URL_LICENSE' => [
        'restFiles' => [
            'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
        ]
    ],
    'TYPO3_URL_EXCEPTION' => [
        'restFiles' => [
            'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
        ]
    ],
    'TYPO3_URL_DONATE' => [
        'restFiles' => [
            'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
        ]
    ],
    'TYPO3_URL_WIKI_OPCODECACHE' => [
        'restFiles' => [
            'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
        ]
    ],
];
